netapp_ontap.models.firmware_update_progress API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.firmware_update_progress`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FirmwareUpdateProgressSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FirmwareUpdateProgress object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `job: JobLink GET`

    The job field of the firmware_update_progress.

  `update_state: List[FirmwareUpdateProgressState] GET`

    The update_state field of the firmware_update_progress.

  `update_type: str GET`

    Specifies the type of update.

    Valid choices:

    - manual_update
    - automatic_update
  `zip_file_name: str GET`

    The zip_file_name field of the firmware_update_progress.

    Example: disk_firmware.zip